@@ -33,8 +33,8 @@ examples <- function(save.png=FALSE) {
 demos <- function(which=c("sources", "protein.equil", "affinity", "NaCl", "density", 
   "ORP", "findit", "ionize", "buffer", "protbuff", "glycinate",
   "mosaic", "copper", "arsenic", "solubility", "gold", "contour", "sphalerite", "zinc",
-  "Shh", "saturation", "adenine", "DEW", "lambda", "berman", "TCA", "aluminum",
-  "AkDi", "comproportionation"), save.png=FALSE) {
+  "Shh", "saturation", "adenine", "DEW", "lambda", "potassium", "TCA", "aluminum",
+  "AkDi", "comproportionation", "Pourbaix", "E_coli"), save.png=FALSE) {
   # run one or more demos from CHNOSZ with ask=FALSE, and return the value of the last one
   for(i in 1:length(which)) {
     # say something so the user sees where we are
