@@ -1,8 +1,8 @@
 # solubility.R: vectorized solubility calculations without uniroot
-# 20181031 jmd
+# 20181031 first version jmd
 # 20181106 work on the output from affinity(); no "equilibrate()" needed!
 # 20190117 add find.IS and test for dissociation reaction
-# 20190730 add codeanal; test all species for dissociation reaction
+# 20210319 use list of aqueous species as main argument (with back-compatibility for affinity output) and handle multiple minerals
 
 ## if this file is interactively sourced, the following are also needed to provide unexported functions:
 #source("equilibrate.R")
@@ -10,8 +10,96 @@
 #source("species.R")
 #source("util.args.R")
 #source("util.character.R")
+#source("mosaic.R")
+#source("basis.R")
 
-solubility <- function(aout, dissociation = NULL, find.IS = FALSE, in.terms.of = NULL, codeanal = FALSE) {
+# Function to calculate solubilities of multiple minerals 20210303
+# species() should be used first to load the minerals (all bearing the same metal)
+# 'iaq' lists aqueous species that can be produced by dissolution of the minerals
+# '...' contains arguments for affinity() or mosaic() (i.e. plotting variables)
+solubility <- function(iaq, ..., in.terms.of = NULL, dissociate = FALSE, find.IS = FALSE) {
+
+  # If iaq is the output of affinity(), use old calling style 20210318
+  if(is.list(iaq)) return(solubility_calc(aout = iaq, in.terms.of = in.terms.of, dissociate = dissociate, find.IS = find.IS))
+  # Check whether to use affinity() or mosaic()
+  affargs <- ddd <- list(...)
+  is.mosaic <- FALSE
+  if(identical(names(ddd)[1], "bases")) {
+    is.mosaic <- TRUE
+    # For getting 'sout' from affinity(), drop arguments specific for mosaic()
+    affargs <- ddd[-1]
+    affargs <- affargs[!names(affargs) %in% c("bases", "stable", "blend")]
+  }
+
+  # Save current thermodynamic system settings
+  thermo <- get("thermo", CHNOSZ)
+  # Use current basis species as a template for the solubility calculations
+  ispecies <- basis()$ispecies
+  logact <- basis()$logact
+  # The current formed species are the minerals to be dissolved
+  mineral <- species()
+  if(is.null(mineral)) stop("please load minerals or gases with species()")
+
+  if(!find.IS) {
+    # Get subcrt() output for all aqueous species and minerals 20210322
+    # Add aqueous species here - the minerals are already present
+    lapply(iaq, species, add = TRUE)
+    # Also add basis species for mosaic()!
+    if(is.mosaic) lapply(unlist(ddd$bases), species, add = TRUE)
+    sout <- suppressMessages(do.call(affinity, c(affargs, return.sout = TRUE)))
+  }
+
+  # Make a list to store the calculated solubilities for each mineral
+  slist <- list()
+  # Loop over minerals
+  for(i in seq_along(mineral$ispecies)) {
+    # Print message
+    message(paste("solubility: calculating for", mineral$name[i]))
+    # Define basis species with the mineral first (so it will be dissolved)
+    ispecies[1] <- mineral$ispecies[i]
+    logact[1] <- mineral$logact[i]
+    # Use numeric values first and put in buffer names second (needed for demo/gold.R)
+    loga.numeric <- suppressWarnings(as.numeric(logact))
+    basis(ispecies, loga.numeric)
+    is.na <- is.na(loga.numeric)
+    if(any(is.na)) basis(rownames(basis())[is.na], logact[is.na])
+    # Add aqueous species (no need to define activities here - they will be calculated by solubility_calc)
+    species(iaq)
+    if(find.IS) {
+      if(is.mosaic) aout <- suppressMessages(mosaic(...)) else aout <- suppressMessages(affinity(...))
+    } else {
+      if(is.mosaic) aout <- suppressMessages(mosaic(..., sout = sout)) else aout <- suppressMessages(affinity(..., sout = sout))
+    }
+    # Calculate solubility of this mineral
+    scalc <- solubility_calc(aout, in.terms.of = in.terms.of, dissociate = dissociate, find.IS = find.IS)
+    # Store the solubilities in the list
+    slist[[i]] <- scalc$loga.balance
+  }
+  
+  # Restore the original thermodynamic system settings
+  assign("thermo", thermo, CHNOSZ)
+
+  if(length(mineral$ispecies) == 1) {
+    # For one mineral, return the results of the solubility calculation
+    scalc
+  } else {
+    # For multiple minerals, the overall solubility is the *minimum* among all the minerals
+    smin <- do.call(pmin, slist)
+    # Put this into the last-computed 'solubility' object
+    scalc$loga.balance <- smin
+    scalc$loga.equil <- slist
+    scalc$species <- mineral
+    # Change the function name stored in the object so diagram() plots loga.balance automatically
+    scalc$fun <- "solubilities"
+    # Return the object
+    scalc
+  }
+}
+
+
+# The "nuts and bolts" of solubility calculations
+# Moved from solubility() to solubility_calc() 20210318
+solubility_calc <- function(aout, dissociate = NULL, find.IS = FALSE, in.terms.of = NULL) {
   ## concept: the logarithms of activities of species at equilibrium are equal to
   ## Astar, the affinities calculated for unit activities of species
 
@@ -20,35 +108,6 @@ solubility <- function(aout, dissociation = NULL, find.IS = FALSE, in.terms.of =
   thisfun <- aout$fun
   if(thisfun=="mosaic") aout <- aout$A.species
 
-  ## does the system involve a dissociation reaction?
-  if(is.null(dissociation)) {
-    # assume FALSE unless determined otherwise
-    dissociation <- FALSE
-    # we can only test for dissociation with more than one basis species 20190730
-    nbasis <- nrow(aout$basis)
-if(codeanal) print(paste("number of basis species:", nbasis))
-    if(nbasis > 1) {
-if(codeanal) print("-- testing for dissociation reactions:")
-      # if the reaction to form the first species involves the second basis species, we consider it to be a dissociation reaction
-      #if(aout$species[1, 2] != 0) {
-      # change this to test for all species 20190730
-      if(all(aout$species[2] != 0)) {
-if(codeanal) print("   reactions to form all species involve the second basis species")
-        # 20190123 (corundum calculation): if there are only H2O, H+, and e-
-        # besides the first basis species, it's not a dissociation reaction
-        nH2O <- sum(rownames(aout$basis) %in% c("H2O", "H+", "e-", "O2", "H2"))
-        if(nbasis > (nH2O + 1)) {
-          # if we got here, and the second basis species is H2O, H+, e-, O2 (or others?), we don't have enough information, so stop
-          if(rownames(aout$basis)[2] %in% c("H2O", "H+", "e-", "O2", "H2")) {
-            stop("Unsure whether the first formation reaction is a dissociation reaction.\nSet the 'dissociation' argument to TRUE or FALSE, or redefine the basis to put a product ion second.")
-          }
-          dissociation <- TRUE
-        } else if(codeanal) print("   the basis consists of only the conserved species and H2O-derived species")
-      } else if(codeanal) print("   at least one formation reaction doesn't involve the second basis species")
-    } else if(codeanal) print("-- no dissociation reactions are possible")
-    message("solubility: test for dissociation reaction returns ", dissociation)
-  } else message("solubility: from argument, dissociation ratio is ", dissociation)
-
   # get starting ionic strength (probably zero, but could be anything set by user)
   IS <- aout$IS
   if(is.null(IS)) IS <- 0
@@ -57,7 +116,6 @@ if(codeanal) print("   reactions to form all species involve the second basis sp
   bout <- balance(aout)
   n.balance <- bout$n.balance
   balance <- bout$balance
-if(codeanal) print(paste0("balancing coefficients [", balance, "]: ", paste(n.balance, collapse = " ")))
   # get logarithm of total activity of the conserved basis species
   logabfun <- function(loga.equil, n.balance) {
     # exponentiate, multiply by n.balance, sum, logarithm
@@ -75,26 +133,18 @@ if(codeanal) print(paste0("balancing coefficients [", balance, "]: ", paste(n.ba
     Astar <- function(i) aout$values[[i]] + aout$species$logact[i]
     loga.equil <- lapply(1:length(aout$values), Astar)
 
-    ## for a dissociation on a *per reaction* (not system) basis,
-    ## apply the divisor here and skip the if(dissociation){} part below
+    ## for a dissociation on a *per reaction* (not system) basis, apply the divisor here
     ## (can be used to reproduce Fig. 4 of Manning et al., 2013)
-    if(is.numeric(dissociation)) {
-if(codeanal) for(ii in 1:length(loga.equil)) print(paste0("loga.equil0 [", aout$species$name[ii], "]: ", round(loga.equil[[ii]], 3)))
-if(codeanal) print(paste0("applying ", dissociation, "-fold dissociation correction (no interaction)"))
-      loga.equil <- lapply(loga.equil, "/", dissociation)
+    if(is.numeric(dissociate)) {
+      loga.equil <- lapply(loga.equil, "/", dissociate)
     }
 
-
     # get the total activity of the balancing basis species
     loga.balance <- logabfun(loga.equil, n.balance)
-if(codeanal & !isTRUE(dissociation)) print(paste0("loga.balance [", balance, "]: ", round(loga.balance, 3)))
 
     # recalculate things for a dissociation reaction (like CaCO3 = Ca+2 + CO3+2)
-    if(isTRUE(dissociation)) {
+    if(isTRUE(dissociate)) {
       ndissoc <- 2
-if(codeanal) print(paste0("loga.balance0 [", balance, "]: ", round(loga.balance, 3)))
-if(codeanal) for(ii in 1:length(loga.equil)) print(paste0("loga.equil0 [", aout$species$name[ii], "]: ", round(loga.equil[[ii]], 3)))
-if(codeanal) print(paste0("applying ", ndissoc, "-fold dissociation correction (with interaction)"))
       # the number of dissociated products is the exponent in the activity product
       loga.dissoc <- loga.balance / ndissoc
       # the contribution to affinity
@@ -103,7 +153,6 @@ if(codeanal) print(paste0("applying ", ndissoc, "-fold dissociation correction (
       aout$values <- mapply("-", aout$values, Adissoc, SIMPLIFY = FALSE)
       loga.equil <- lapply(1:length(aout$values), Astar)
       loga.balance <- logabfun(loga.equil, n.balance)
-if(codeanal) print(paste0("loga.balance [", balance, "]: ", round(loga.balance, 3)))
       # check that the new loga.balance == loga.dissoc
       # TODO: does this work for non-1:1 species?
       stopifnot(all.equal(loga.balance, loga.dissoc))
@@ -115,7 +164,7 @@ if(codeanal) print(paste0("loga.balance [", balance, "]: ", round(loga.balance,
     sum.mZ2 <- 0
     ion.names <- character()
     # is there an ion in the basis species?
-    if(dissociation) {
+    if(dissociate) {
       basis.ion <- rownames(aout$basis)[2]
       Z.basis.ion <- makeup(basis.ion)["Z"]
       if(!is.na(Z.basis.ion)) {
@@ -170,7 +219,6 @@ if(codeanal) print(paste0("loga.balance [", balance, "]: ", round(loga.balance,
     ibalance <- which.balance(aout$species)
     coeff <- sbasis[, ibalance][1]
     loga.balance <- loga.balance - log10(coeff)
-if(codeanal) print(paste0("loga.balance [in terms of ", in.terms.of, "]: ", round(loga.balance, 3)))
   }
 
   # make the output (we don't deal with normalized formulas yet, so for now m.balance==n.balance)
@@ -181,3 +229,4 @@ if(codeanal) print(paste0("loga.balance [in terms of ", in.terms.of, "]: ", roun
   c(aout, list(balance=bout$balance, m.balance=bout$n.balance, n.balance=bout$n.balance, in.terms.of=in.terms.of,
     loga.balance=loga.balance, Astar=loga.equil, loga.equil=loga.equil))
 }
+
