@@ -3,7 +3,7 @@
 
 aminoacids <- function(nchar=1, which=NULL) {
   # return the abbreviations or names of the amino acids
-  # the following are all in the same order as thermo$protein
+  # the following are all in the same order as thermo()$protein
   # the single-letter codes
   aa1 <- c("A", "C", "D", "E", "F", "G", "H", "I", "K", "L", 
            "M", "N", "P", "Q", "R", "S", "T", "V", "W", "Y")
@@ -18,7 +18,7 @@ aminoacids <- function(nchar=1, which=NULL) {
   aacharged <- c("alanine", "cysteinate", "aspartate", "glutamate", "phenylalanine", 
     "glycine", "histidinium", "isoleucine", "lysinium", "leucine", "methionine", "asparagine", 
     "proline", "glutamine", "argininium", "serine", "threonine", "valine", "tryptophan", "tyrosinate")
-  # defaults are in the same order as in thermo$protein
+  # defaults are in the same order as in thermo()$protein
   if(is.null(which)) which <- aa1
   # figure out which amino acids are wanted (can use 1- or 3-letter codes, or neutral names)
   if(all(nchar(which)==1)) iaa <- match(which, aa1)
@@ -46,7 +46,7 @@ nucleic.formula <- function(nucleic=NULL) {
   # the species indices of the bases, in the order appearing above
   i.base <- suppressMessages(info(names[!ina], check.it=FALSE))
   # the chemical formula of bases
-  f.base <- get("thermo", CHNOSZ)$obigt$formula[i.base]
+  f.base <- get("thermo", CHNOSZ)$OBIGT$formula[i.base]
   # loop over the base counts
   f.out <- character()
   for(i in 1:nrow(nucleic)) {
