@@ -1,4 +1,5 @@
 # plot temperature dependence of log K for some dehydration reactions
+library(CHNOSZ)
 
 # the RSVGTipsDevice package allows us to create an SVG file with
 # tooltips and hyperlinks
@@ -48,8 +49,8 @@ for(i in 1:length(reactants)) {
 
   # names
   for(j in 1:2) {
-    formula <- thermo()$obigt$formula[s$reaction$ispecies[j]]
-    key1 <- thermo()$obigt$ref1[s$reaction$ispecies[j]]
+    formula <- thermo()$OBIGT$formula[s$reaction$ispecies[j]]
+    key1 <- thermo()$OBIGT$ref1[s$reaction$ispecies[j]]
     # remove suffix from the key (e.g. "DLH06 [S15]" --> "DLH06")
     key1 <- strsplit(key1, " ")[[1]][1]
     ikey1 <- which(thermo()$refs$key==key1)
@@ -62,7 +63,7 @@ for(i in 1:length(reactants)) {
     name <- gsub("-.*", "", s$reaction$name[j])
     text(T[ilab[i]] + dx, s$out$logK[ilab[i]] + dy, name, adj=1, srt=srt[i])
     # add a second reference link if needed
-    key2 <- thermo()$obigt$ref2[s$reaction$ispecies[j]]
+    key2 <- thermo()$OBIGT$ref2[s$reaction$ispecies[j]]
     if(!is.na(key2)) {
       ikey2 <- which(thermo()$refs$key==key2)
       URL2 <- thermo()$refs$URL[ikey2]
