@@ -7,26 +7,26 @@ test_that("recalculated values from SK95 are correctly entered in OBIGT", {
   # thermodynamic data entries for amino acid glycinate and alanate complexes
   # (no longer in default database)
   reset()
-  add.obigt("OldAA")
+  add.OBIGT("OldAA")
   iaa <- info(c("alanate", "glycinate"))
-  iGly <- grep("\\(Gly\\)\\+$", thermo()$obigt$name)
-  iGly2 <- grep("\\(Gly\\)2$", thermo()$obigt$name)
-  iAla <- grep("\\(Ala\\)\\+$", thermo()$obigt$name)
-  iAla2 <- grep("\\(Ala\\)2$", thermo()$obigt$name)
+  iGly <- grep("\\(Gly\\)\\+$", thermo()$OBIGT$name)
+  iGly2 <- grep("\\(Gly\\)2$", thermo()$OBIGT$name)
+  iAla <- grep("\\(Ala\\)\\+$", thermo()$OBIGT$name)
+  iAla2 <- grep("\\(Ala\\)2$", thermo()$OBIGT$name)
   # get values used in OBIGT
-  aa_GHS_OBIGT <- thermo()$obigt[iaa, c("G", "H", "S")]
-  Gly_GHS_OBIGT <- thermo()$obigt[iGly, c("G", "H", "S")]
-  Gly2_GHS_OBIGT <- thermo()$obigt[iGly2, c("G", "H", "S")]
-  Ala_GHS_OBIGT <- thermo()$obigt[iAla, c("G", "H", "S")]
-  Ala2_GHS_OBIGT <- thermo()$obigt[iAla2, c("G", "H", "S")]
+  aa_GHS_OBIGT <- thermo()$OBIGT[iaa, c("G", "H", "S")]
+  Gly_GHS_OBIGT <- thermo()$OBIGT[iGly, c("G", "H", "S")]
+  Gly2_GHS_OBIGT <- thermo()$OBIGT[iGly2, c("G", "H", "S")]
+  Ala_GHS_OBIGT <- thermo()$OBIGT[iAla, c("G", "H", "S")]
+  Ala2_GHS_OBIGT <- thermo()$OBIGT[iAla2, c("G", "H", "S")]
   # get values from SK95
   SK95 <- system.file("extdata/adds/SK95.csv", package="CHNOSZ")
-  add.obigt(SK95)
-  aa_GHS_SK95 <- thermo()$obigt[iaa, c("G", "H", "S")]
-  Gly_GHS_SK95 <- thermo()$obigt[iGly, c("G", "H", "S")]
-  Gly2_GHS_SK95 <- thermo()$obigt[iGly2, c("G", "H", "S")]
-  Ala_GHS_SK95 <- thermo()$obigt[iAla, c("G", "H", "S")]
-  Ala2_GHS_SK95 <- thermo()$obigt[iAla2, c("G", "H", "S")]
+  add.OBIGT(SK95)
+  aa_GHS_SK95 <- thermo()$OBIGT[iaa, c("G", "H", "S")]
+  Gly_GHS_SK95 <- thermo()$OBIGT[iGly, c("G", "H", "S")]
+  Gly2_GHS_SK95 <- thermo()$OBIGT[iGly2, c("G", "H", "S")]
+  Ala_GHS_SK95 <- thermo()$OBIGT[iAla, c("G", "H", "S")]
+  Ala2_GHS_SK95 <- thermo()$OBIGT[iAla2, c("G", "H", "S")]
   # calculate differences for alanate and glycinate
   # nb. round values to avoid floating-point difficulties with unique() etc.
   Ala_GHS_Delta <- round(aa_GHS_SK95[1, ] - aa_GHS_OBIGT[1, ], 2)
@@ -47,12 +47,12 @@ test_that("recalculated values for HSiO3- match those in original reference", {
   iHSiO3 <- info("HSiO3-")
   # get values used in OBIGT
   reset()
-  SiO2_GHS_OBIGT <- thermo()$obigt[iSiO2, c("G", "H", "S")]
-  HSiO3_GHS_OBIGT <- thermo()$obigt[iHSiO3, c("G", "H", "S")]
+  SiO2_GHS_OBIGT <- thermo()$OBIGT[iSiO2, c("G", "H", "S")]
+  HSiO3_GHS_OBIGT <- thermo()$OBIGT[iHSiO3, c("G", "H", "S")]
   # get values from SSH97
-  add.obigt("SLOP98")
-  SiO2_GHS_SSH97 <- thermo()$obigt[iSiO2, c("G", "H", "S")]
-  HSiO3_GHS_SSH97 <- thermo()$obigt[iHSiO3, c("G", "H", "S")]
+  add.OBIGT("SLOP98")
+  SiO2_GHS_SSH97 <- thermo()$OBIGT[iSiO2, c("G", "H", "S")]
+  HSiO3_GHS_SSH97 <- thermo()$OBIGT[iHSiO3, c("G", "H", "S")]
   # calculate differences
   OBIGT_Delta <- HSiO3_GHS_OBIGT - SiO2_GHS_OBIGT
   SSH97_Delta <- HSiO3_GHS_SSH97 - SiO2_GHS_SSH97
