@@ -18,31 +18,6 @@ test_that("basis.logact only accepts defined elements", {
   basis(c("graphite", "H2"), c("cr", "gas"))
   # we can't get basis activities with one element
   expect_error(basis.logact(c(C=1)), "number of elements in 'emu' is less than those in basis")
-  # get some potentials of C, H and O
-  ispecies <- info(c("ethane", "propane", "acetic acid", "propanoic acid"))  
-  w <- run.wjd(ispecies, as.chemical.formula(colMeans(i2A(ispecies))))
-  ep <- equil.potentials(w)
-  # try to calculate log activities of basis species: get an error
-  expect_error(basis.logact(ep), "element\\(s\\) O not found in basis")
-})
-
-test_that("equil.potentials - basis.logact - element.mu makes a roundtrip at 25 and 99 degrees C", {
-  basis(c("graphite", "H2", "O2"), c("cr", "gas", "gas"))
-  ispecies <- info(c("ethane", "propane", "acetic acid", "propanoic acid"))  
-  # at 25 degrees C
-  w25 <- run.wjd(ispecies, as.chemical.formula(colMeans(i2A(ispecies))))
-  ep25 <- equil.potentials(w25)
-  bl25 <- basis.logact(ep25)
-  # set the activities of the bais species
-  basis(names(bl25), bl25)
-  # element.mu() calculates the chemical potentials of the elements from the current setting of basis species
-  expect_equal(element.mu(), ep25)
-  # at 99 degrees C
-  w99 <- run.wjd(ispecies, as.chemical.formula(colMeans(i2A(ispecies))), T=99)
-  ep99 <- equil.potentials(w99)
-  bl99 <- basis.logact(ep99, T=99)
-  basis(names(bl99), bl99)
-  expect_equal(element.mu(T=99), ep99)
 })
 
 # 20181111
@@ -54,3 +29,27 @@ test_that("swapping works with a buffer (no recalculation of activities)", {
   # note: logact includes "PPM" for O2 (old) and H2 (new)
   expect_identical(oldb$logact, newb$logact)
 })
+
+# 20200728 moved from swap-basis.Rd
+test_that("swapping doesn't affect affinities of formation reactions of species", {
+  ## swapping basis species while species are defined
+  ## and using numeric species indices
+  basis("MgCHNOPS+") 
+  # load some Mg-ATP species
+  species(c("MgATP-2", "MgHATP-", "MgH2ATP", "Mg2ATP"))
+  # swap in CO2(g) for CO2(aq)
+  swap.basis("CO2", "carbon dioxide")
+  a1 <- affinity()
+  # swap in CH4(g) for CO2(g)
+  swap.basis("carbon dioxide", "methane")
+  a2 <- affinity()
+  # the equilibrium fugacity of CH4 is *very* low
+  # swap in CO2(aq) for CH4(g)
+  swap.basis("methane", "CO2")
+  a3 <- affinity()
+  # swapping the basis species didn't affect the affinities
+  # of the formation reactions of the species, since
+  # the chemical potentials of the elements were unchanged
+  expect_equal(a1$values, a2$values)
+  expect_equal(a1$values, a3$values)
+})
